<?php

namespace Drupal\rest_role_restrict\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\Role;

/**
 * Configure which roles can access REST API.
 */
class SettingsForm extends ConfigFormBase {

    protected function getEditableConfigNames() {
        return ['rest_role_restrict.settings'];
    }

    public function getFormId() {
        return 'rest_role_restrict_settings_form';
    }

    public function buildForm(array $form, FormStateInterface $form_state) {
        $roles = Role::loadMultiple();
        $options = [];

        foreach ($roles as $role) {
            $options[$role->id()] = $role->label();
        }

        $config = $this->config('rest_role_restrict.settings');

        $form['allowed_roles'] = [
            '#type' => 'checkboxes',
            '#title' => $this->t('Allowed Roles'),
            '#description' => $this->t('Only users with these roles will be able to access REST API endpoints.'),
            '#options' => $options,
            '#default_value' => $config->get('allowed_roles') ?: [],
        ];

        return parent::buildForm($form, $form_state);
    }

    public function submitForm(array &$form, FormStateInterface $form_state) {
        $this->config('rest_role_restrict.settings')
            ->set('allowed_roles', array_filter($form_state->getValue('allowed_roles')))
            ->save();

        parent::submitForm($form, $form_state);
    }
}
